@@ -53,9 +53,10 @@ class ProcessExecutionError(IOError):
         message = _('%(description)s\nCommand: %(cmd)s\n'
                     'Exit code: %(exit_code)s\nStdout: %(stdout)r\n'
                     'Stderr: %(stderr)r') % {
-                    'description': description, 'cmd': cmd,
-                    'exit_code': exit_code, 'stdout': stdout,
-                    'stderr': stderr}
+                        'description': description, 'cmd': cmd,
+                        'exit_code': exit_code, 'stdout': stdout,
+                        'stderr': stderr
+                    }
         IOError.__init__(self, message)
 
 
@@ -151,6 +152,10 @@ class OvercloudRoleExists(DuplicateEntry):
     message = _("Overcloud role with name %(name)s already exists.")
 
 
+class OvercloudRoleInUse(TuskarException):
+    message = _('Role %(name)s is in use by an overcloud.')
+
+
 class OvercloudRoleCountExists(DuplicateEntry):
     message = _("Count for overcloud %(cloud)s and "
                 "role %(role)s already exists.")
@@ -166,3 +171,23 @@ class DuplicateAttribute(DuplicateEntry):
 
 class ConfigNotFound(TuskarException):
     message = _("Could not find config at %(path)s")
+
+
+class InvalidHeatTemplate(TuskarException):
+    message = _("Validation of the Heat Template failed.")
+
+
+class StackNotFound(NotFound):
+    message = _("The Stack for this Overcloud can't be found.")
+
+
+class StackAlreadyCreated(DuplicateEntry):
+    message = _("The Stack for this Overcloud already exists.")
+
+
+class HeatTemplateUpdateFailed(TuskarException):
+    message = _("The Heat template failed to update.")
+
+
+class HeatTemplateCreateFailed(TuskarException):
+    message = _("The Heat template failed to create.")
